import axios, { AxiosRequestConfig, Method } from 'axios';
import jwt_decode from 'jwt-decode';
import { store } from '../store';

export const request = (
  method: Method,
  url: string,
  data: {} | null = null,
  headers: {} | null = null
) => {
  const API = axios.create({ baseURL: process.env.REACT_APP_BASE_URL });

  API.interceptors.request.use(
    async config => {
      const {} = store.getState();

      const { exp }: { exp: number } = jwt_decode('');

      if (exp * 1000 < Date.now()) {
        if (config.headers) config.headers.authorization = `Bearer `;
      }

      return config;
    },
    error => {
      return Promise.reject(error);
    },
  );

  return API.request({ method, url, data, headers } as AxiosRequestConfig);
};
